==> pyverm-0.1.1-py3-none-any.whl: pyverm/__version__.py <==
########################################################################
#                                                                      #
# Copyright (C) 2018,  Marius Hürzeler                                 #
#                                                                      #
# This file is part of PyVerm.                                         #
#                                                                      #
# PyVerm is free software: you can redistribute it and/or modify       #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation, either version 3 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# PyVerm is distributed in the hope that it will be useful,            #
# but WITHOUT ANY WARRANTY; without even the implied warranty of       #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        #
# GNU General Public License for more details.                         #
#                                                                      #
# You should have received a copy of the GNU General Public License    #
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.      #
#                                                                      #
########################################################################

"""
Contains all the Package-Metadata


"""

__title__ = "pyverm"
__description__ = 'Modul for geodetic and surveying calculations'
__url__ = "https://pyverm.readthedocs.io/en/latest/"
__version__ = "0.1.1"
__release__ = __version__ + ""
__author__ = 'Marius Huerzeler'
__author_email__ = 'huerzeler.marius@gmail.com'
__license__ = 'GNU GPLv3+'
__copyright__ = 'Copyright 2018 Marius Huerzeler'

==> pyverm-0.1.3.dev1-py3-none-any.whl: pyverm/__version__.py <==
########################################################################
#                                                                      #
# Copyright (C) 2018,  Marius Hürzeler                                 #
#                                                                      #
# This file is part of PyVerm.                                         #
#                                                                      #
# PyVerm is free software: you can redistribute it and/or modify       #
# it under the terms of the GNU General Public License as published by #
# the Free Software Foundation, either version 3 of the License, or    #
# (at your option) any later version.                                  #
#                                                                      #
# PyVerm is distributed in the hope that it will be useful,            #
# but WITHOUT ANY WARRANTY; without even the implied warranty of       #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        #
# GNU General Public License for more details.                         #
#                                                                      #
# You should have received a copy of the GNU General Public License    #
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.      #
#                                                                      #
########################################################################

"""
Contains all the Package-Metadata

"""

__title__ = "pyverm"
__description__ = 'Modul for geodetic and surveying calculations'
__url__ = "https://pyverm.readthedocs.io/en/latest/"
__version__ = "0.1.3"
__release__ = __version__ + ".dev1"
__author__ = 'Marius Huerzeler'
__author_email__ = 'huerzeler.marius@gmail.com'
__license__ = 'GNU GPLv3+'
__copyright__ = 'Copyright 2018 Marius Huerzeler'
